function is_value_in_list (value, list)
  for i, v in pairs (list) do
    if v == value then
      return true
    end
  end
  return false
end

script.on_event(defines.events.on_tick, function(event)
  local chests_amount = #global.loot_chests
  if chests_amount == 0 then return end
  local index = global.next_index
  if index > chests_amount then
    index = 1
  end
  
  local chest = global.loot_chests[index]
  local chest_entity = chest.entity

  if not chest or not chest_entity.valid then -- no chest
    table.remove (global.next_index, index) -- keep nice table
    return
  end
  
  local surface = chest_entity.surface
  local chest_position = chest_entity.position
  
  local areaToCheck = {left_top = {chest_position.x-10, chest_position.y-10}, right_bottom = {chest_position.x+10, chest_position.y+10}}
  
  local entities
  
  -- local signals = chest_entity.get_merged_signals(circuit_connector)
  local signals = chest_entity.get_merged_signals()
  
  local signal_names = {}
  
  if signals then
    for i, signal in pairs (signals) do
      local signalID = signal.signal
      local signal_type = signalID.type
      local signal_name = signalID.name
      if signal_type == 'item' then
        signal_names[#signal_names+1] = signal_name
      end
    end
  end
  
  local item_entities = surface.find_entities_filtered{area = areaToCheck, type = "item-entity"}
  
  if not item_entities then
    global.next_index = index + 1
    return
  end
  
  local loot = {}
  
  for i, item_entity in pairs (item_entities) do
    if item_entity.valid then
      local stack = item_entity.stack
      local name = stack.name
      if (signals and is_value_in_list (name, signal_names)) or not (signals) then
        if stack.valid then
          if chest_entity.can_insert(stack) then
            -- here rendering
            chest_entity.insert(stack)
            item_entity.destroy ()
          end
        else
          game.print ('stack.valid is false: '..item_entity.name)
        end
      end
    else
      game.print ('item_entity.valid is false: '..item_entity.name)
    end
  end
  global.next_index = index + 1
end)


function on_init ()
  if not global.loot_chests then global.loot_chests = {} end
  if not global.next_index then global.next_index = 1 end
end

function on_configuration_changed ()
  if not global.loot_chests then global.loot_chests = {} end
  if not global.next_index then global.next_index = 1 end
  for i, surface in pairs (game.surfaces) do
    local entities = surface.find_entities_filtered{name = 'artifact-loot-chest'}
    if entities then
      for j, entity in pairs (entities) do
        table.insert (global.loot_chests, {entity = entity}) -- we are need nice table
      end
    end
  end
end


function on_any_built (event)
  local entity = event.created_entity
  if entity.name == 'artifact-loot-chest' then
    table.insert (global.loot_chests, {entity = entity}) -- we are need nice table
  end
end

script.on_init(on_init)

script.on_configuration_changed(on_configuration_changed)

script.on_event(defines.events.on_built_entity, on_any_built)

script.on_event(defines.events.on_robot_built_entity, on_any_built)





